@@ -18,7 +18,7 @@ with_parameters_test_that(
     if (test_outcome == "success") {
       testthat::expect_success(testthat::expect_true(case))
     } else {
-      failure_message <- "`case` (isn't true|is not TRUE)"
+      failure_message <- "`case` (isn't true|is not TRUE|to be TRUE)"
       testthat::expect_failure(testthat::expect_true(case), failure_message)
     }
   },
@@ -45,7 +45,7 @@ with_parameters_test_that(
   },
   .cases = data.frame(
     logical = FALSE,
-    number = 1,
+    number = 1.0,
     string = "hello",
     stringsAsFactors = FALSE
   )
@@ -57,8 +57,8 @@ with_parameters_test_that(
     testthat::expect_length(vec, len)
   },
   cases(
-    one = list(vec = 1, len = 1),
-    ten = list(vec = 1:10, len = 10)
+    one = list(vec = 1L, len = 1L),
+    ten = list(vec = 1:10, len = 10L)
   )
 )
 
@@ -67,19 +67,19 @@ with_parameters_test_that(
   {
     testthat::expect_identical(.test_name, "vec=1, len=1")
   },
-  cases(list(vec = 1, len = 1))
+  cases(list(vec = 1L, len = 1L))
 )
 
 with_parameters_test_that(
   "Data frames can be passed to cases:",
   {
     result <- rlang::as_function(FUN)(input)
-    testthat::expect_equal(result, out)
+    testthat::expect_identical(result, out)
   },
   .cases = tibble::tribble(
     ~.test_name, ~FUN, ~input, ~out,
-    "times", ~ .x * 2, 2, 4,
-    "plus", ~ .x + 3, 3, 6
+    "times", ~ .x * 2L, 2L, 4L,
+    "plus", ~ .x + 3L, 3L, 6L
   )
 )
 
@@ -89,9 +89,9 @@ with_parameters_test_that(
     testthat::expect_warning(fun(), regexp = message)
   },
   cases(
-    shouldnt_warn = list(fun = function() 1 + 1, message = NA),
+    shouldnt_warn = list(fun = \() 1L + 1L, message = NA),
     should_warn = list(
-      fun = function() warning("still warn!"),
+      fun = \() warning("still warn!", call. = FALSE),
       message = "still warn"
     )
   )
@@ -103,31 +103,31 @@ test_that("Patrick catches the right class of warning", {
       rlang::warn("New warning", class = "testthat_braces_warning")
     }
   )
-  testthat::expect_warning(
-    with_parameters_test_that(
-      "No more warnings:",
-      {
-        testthat::expect_true(truth)
-      },
-      truth = TRUE
-    ),
-    regexp = NA
-  )
+
+  with_parameters_test_that(
+    "No more warnings:",
+    {
+      testthat::expect_true(truth)
+    },
+    truth = TRUE
+  ) |>
+    testthat::expect_no_warning()
 })
 
 # From testthat/tests/testthat/test-test-that.R
 # Use for checking that line numbers are still correct
 expectation_lines <- function(code) {
-  srcref <- attr(substitute(code), "srcref")
-  if (!is.list(srcref)) {
+  code_srcref <- attr(substitute(code), "srcref")
+  if (!is.list(code_srcref)) {
     stop("code doesn't have srcref", call. = FALSE)
   }
 
   results <- testthat::with_reporter("silent", code)$expectations()
-  unlist(lapply(results, function(x) x$srcref[1])) - srcref[[1]][1]
+  unlist(lapply(results, \(x) x$srcref[1L])) - code_srcref[[1L]][1L]
 }
 
 test_that("patrick reports the correct line numbers", {
+  # nolint start: indentation_linter.
   lines <- expectation_lines({
                                                  # line 1
     with_parameters_test_that("simple", {        # line 2
@@ -138,92 +138,86 @@ test_that("patrick reports the correct line numbers", {
       false = list(truth = FALSE)
     ))
   })
-  expect_equal(lines, c(3, 3))
+  # nolint end: indentation_linter.
+  expect_identical(lines, c(3L, 3L))
 })
 
 test_that('patrick gives a deprecation warning for "test_name"', {
-  testthat::expect_warning(
-    with_parameters_test_that(
-      "Warn about `test_name` argument:",
-      {
-        testthat::expect_true(truth)
-      },
-      truth = TRUE,
-      test_name = "true"
-    ),
-    regexp = "deprecated"
-  )
+  with_parameters_test_that(
+    "Warn about `test_name` argument:",
+    {
+      testthat::expect_true(truth)
+    },
+    truth = TRUE,
+    test_name = "true"
+  ) |>
+    testthat::expect_warning(regexp = "deprecated")
 
-  testthat::expect_warning(
-    with_parameters_test_that(
-      "Warn about `test_name` column:",
-      {
-        testthat::expect_true(truth)
-      },
-      .cases = tibble::tribble(
-        ~test_name, ~truth,
-        "true", TRUE
-      )
-    ),
-    regexp = "deprecated"
-  )
+  with_parameters_test_that(
+    "Warn about `test_name` column:",
+    {
+      testthat::expect_true(truth)
+    },
+    .cases = tibble::tribble(
+      ~test_name, ~truth,
+      "true", TRUE
+    )
+  ) |>
+    testthat::expect_warning(regexp = "deprecated")
 })
 
 expectation_names <- function(code) {
   expectations <- testthat::with_reporter("silent", code)$expectations()
-  vapply(expectations, function(e) as.character(e$test), character(1L))
+  vapply(expectations, \(e) as.character(e$test), character(1L))
 }
 
 test_that("glue-formatted descriptions and test names supported", {
-  expect_identical(
-    expectation_names(with_parameters_test_that(
-      "testing for (x, y, z) = ({x}, {y}, {z})",
-      {
-        testthat::expect_true(x + y + z > 0)
-      },
-      x = 1:10, y = 2:11, z = 3:12
-    )),
-    sprintf("testing for (x, y, z) = (%d, %d, %d)", 1:10, 2:11, 3:12)
-  )
+  with_parameters_test_that(
+    "testing for (x, y, z) = ({x}, {y}, {z})",
+    {
+      testthat::expect_gt(x + y + z, 0L)
+    },
+    x = 1:10, y = 2:11, z = 3:12
+  ) |>
+    expectation_names() |>
+    expect_identical(
+      sprintf("testing for (x, y, z) = (%d, %d, %d)", 1:10, 2:11, 3:12)
+    )
 
-  expect_identical(
-    expectation_names(with_parameters_test_that(
-      "testing for (x, y, z):",
-      {
-        testthat::expect_true(x + y + z > 0)
-      },
-      x = 1:10, y = 2:11, z = 3:12,
-      .test_name = "({x}, {y}, {z})"
-    )),
-    sprintf("testing for (x, y, z): (%d, %d, %d)", 1:10, 2:11, 3:12)
-  )
+  with_parameters_test_that(
+    "testing for (x, y, z):",
+    {
+      testthat::expect_gt(x + y + z, 0L)
+    },
+    x = 1:10, y = 2:11, z = 3:12,
+    .test_name = "({x}, {y}, {z})"
+  ) |>
+    expectation_names() |>
+    expect_identical(
+      sprintf("testing for (x, y, z): (%d, %d, %d)", 1:10, 2:11, 3:12)
+    )
 
-  expect_warning(
-    expect_warning(
-      expect_identical(
-        expectation_names(with_parameters_test_that(
-          "testing for (x, y): ({x}, {y})",
-          {
-            testthat::expect_equal(x, y)
-          },
-          x = list(NULL, 1:10), y = list(NULL, 1:10)
-        )),
-        sprintf(
-          "testing for (x, y): ({x}, {y}) x=%1$s, y=%1$s",
-          c("NULL", toString(1:10))
-        )
-      ),
-      "produced output of length 0"
-    ),
-    "produced output of length 10"
-  )
+  with_parameters_test_that(
+    "testing for (x, y): ({x}, {y})",
+    {
+      testthat::expect_identical(x, y)
+    },
+    x = list(NULL, 1:10), y = list(NULL, 1:10)
+  ) |>
+    expectation_names() |>
+    expect_identical(sprintf(
+      "testing for (x, y): ({x}, {y}) x=%1$s, y=%1$s",
+      c("NULL", toString(1:10))
+    )) |>
+    expect_warning("produced output of length 0")
+    expect_warning("produced output of length 10")
 
   # but fail kindly for potential accidental use of glue
   #   c.f. https://github.com/r-lib/lintr/issues/2706
   expect_error(
     with_parameters_test_that("a{b}", {
       expect_true(TRUE)
-    }, .cases = data.frame(d = 1)),
+    }, .cases = data.frame(d = 1L)),
     "Attempt to interpret test stub 'a{b}' with glue failed",
     fixed = TRUE
   )
@@ -231,6 +225,6 @@ test_that("glue-formatted descriptions and test names supported", {
   expect_no_error(
     with_parameters_test_that("a{b}", {
       expect_true(TRUE)
-    }, .cases = data.frame(d = 1), .interpret_glue = FALSE)
+    }, .cases = data.frame(d = 1L), .interpret_glue = FALSE)
   )
 })
